@@ -1,5 +1,5 @@
 from . import util
-from pyokc import User
+from okcupyd import User
 
 
 @util.use_cassette('user_no_picture')
@@ -10,7 +10,7 @@ def test_handle_no_pictures():
 @util.use_cassette('user_get_threads')
 def test_get_inbox():
     user = User()
-    assert len(user.inbox.items) == 2
+    assert len(user.inbox.items) == 1
 
     for message_thread in user.inbox:
         for message in message_thread.messages:
